@@ -1,4 +1,4 @@
-use mysql_binlog::event::EventData;
+use crate::mysql_binlog::event::EventData;
 
 #[derive(Debug)]
 pub struct Event {
